Documentation
¶
Overview ¶
Package render provides output renderers for fo's visualization patterns.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LLM ¶
type LLM struct{}
LLM renders patterns as terse plain text optimized for AI consumption. Zero ANSI codes, deterministic sort, SCOPE line, importance-budgeted truncation.
type Terminal ¶
type Terminal struct {
// contains filtered or unexported fields
}
Terminal renders patterns as styled terminal output via lipgloss.
func NewTerminal ¶
NewTerminal creates a terminal renderer with the given theme.
type Theme ¶
type Theme struct {
Name string
Primary lipgloss.Style
Success lipgloss.Style
Warning lipgloss.Style
Error lipgloss.Style
Muted lipgloss.Style
Bold lipgloss.Style
Icons ThemeIcons
}
Theme defines colors and icons for terminal rendering.
func ThemeByName ¶
ThemeByName returns a theme by name, defaulting to DefaultTheme.
Click to show internal directories.
Click to hide internal directories.